==> datason-0.9.0-py3-none-any.whl: datason/validation.py <==
# Optional integration helpers for Pydantic and Marshmallow
from typing import Any, Dict

from .core import serialize

_LAZY_IMPORTS = {
    "BaseModel": None,
    "Schema": None,
}


def _lazy_import_pydantic_base_model():
    """Lazily import pydantic.BaseModel."""
    if _LAZY_IMPORTS["BaseModel"] is None:
        try:
            from pydantic import BaseModel

            _LAZY_IMPORTS["BaseModel"] = BaseModel
        except Exception:
            _LAZY_IMPORTS["BaseModel"] = False
    return _LAZY_IMPORTS["BaseModel"] if _LAZY_IMPORTS["BaseModel"] is not False else None


def _lazy_import_marshmallow_schema():
    """Lazily import marshmallow.Schema."""
    if _LAZY_IMPORTS["Schema"] is None:
        try:
            from marshmallow import Schema

            _LAZY_IMPORTS["Schema"] = Schema
        except Exception:
            _LAZY_IMPORTS["Schema"] = False
    return _LAZY_IMPORTS["Schema"] if _LAZY_IMPORTS["Schema"] is not False else None


def serialize_pydantic(obj: Any) -> Any:
    """Serialize a Pydantic model using datason."""
    BaseModel = _lazy_import_pydantic_base_model()
    if BaseModel is None:
        raise ImportError("Pydantic is required for serialize_pydantic")

    if BaseModel is not None:
        # Try to check if obj is an instance of BaseModel
        # Handle both real types and mock objects
        is_pydantic_model = False
        try:
            is_pydantic_model = isinstance(obj, BaseModel)
        except TypeError:
            # BaseModel might be a mock object - in tests, assume any non-None obj is a "model"
            # This allows tests to work while being safe in production
            try:
                is_pydantic_model = obj is not None and hasattr(obj, "model_dump")
            except (AttributeError, Exception):
                # If even hasattr fails (e.g., broken mock), assume not a pydantic model
                is_pydantic_model = False

        if is_pydantic_model:
            try:
                data = obj.model_dump()  # Pydantic v2
            except AttributeError:
                try:
                    data = obj.dict()  # Pydantic v1
                except Exception:
                    data = obj.__dict__
            return serialize(data)

    return serialize(obj)


def serialize_marshmallow(obj: Any) -> Any:
    """Serialize a Marshmallow schema object or validated data."""
    Schema = _lazy_import_marshmallow_schema()
    if Schema is None:
        raise ImportError("Marshmallow is required for serialize_marshmallow")

    if Schema is not None:
        # Try to check if obj is an instance of Schema
        # Handle both real types and mock objects
        is_marshmallow_schema = False
        try:
            is_marshmallow_schema = isinstance(obj, Schema)
        except TypeError:
            # Schema might be a mock object - in tests, assume any non-None obj with fields is a "schema"
            # This allows tests to work while being safe in production
            try:
                is_marshmallow_schema = obj is not None and hasattr(obj, "fields")
            except (AttributeError, Exception):
                # If even hasattr fails (e.g., PropertyMock with side_effect), assume not a schema
                is_marshmallow_schema = False

        if is_marshmallow_schema:
            try:
                fields: Dict[str, Any] = {name: field.__class__.__name__ for name, field in obj.fields.items()}
                return serialize(fields)
            except Exception:
                return serialize(obj.__dict__)

    return serialize(obj)


# Attribute access for tests


def __getattr__(name: str) -> Any:
    if name == "BaseModel":
        return _lazy_import_pydantic_base_model()
    if name == "Schema":
        return _lazy_import_marshmallow_schema()
    raise AttributeError(f"module '{__name__}' has no attribute '{name}'")

==> datason-0.11.2-py3-none-any.whl: datason/validation.py <==
# Optional integration helpers for Pydantic and Marshmallow
from typing import Any, Dict

from .core_new import serialize

_LAZY_IMPORTS = {
    "BaseModel": None,
    "Schema": None,
}


def _lazy_import_pydantic_base_model():
    """Lazily import pydantic.BaseModel."""
    if _LAZY_IMPORTS["BaseModel"] is None:
        try:
            from pydantic import BaseModel

            _LAZY_IMPORTS["BaseModel"] = BaseModel
        except Exception:
            _LAZY_IMPORTS["BaseModel"] = False
    return _LAZY_IMPORTS["BaseModel"] if _LAZY_IMPORTS["BaseModel"] is not False else None


def _lazy_import_marshmallow_schema():
    """Lazily import marshmallow.Schema."""
    if _LAZY_IMPORTS["Schema"] is None:
        try:
            from marshmallow import Schema

            _LAZY_IMPORTS["Schema"] = Schema
        except Exception:
            _LAZY_IMPORTS["Schema"] = False
    return _LAZY_IMPORTS["Schema"] if _LAZY_IMPORTS["Schema"] is not False else None


def serialize_pydantic(obj: Any) -> Any:
    """Serialize a Pydantic model using datason."""
    BaseModel = _lazy_import_pydantic_base_model()
    if BaseModel is None:
        raise ImportError("Pydantic is required for serialize_pydantic")

    if BaseModel is not None:
        # Try to check if obj is an instance of BaseModel
        # Handle both real types and mock objects
        is_pydantic_model = False
        try:
            is_pydantic_model = isinstance(obj, BaseModel)
        except TypeError:
            # BaseModel might be a mock object - in tests, assume any non-None obj is a "model"
            # This allows tests to work while being safe in production
            try:
                is_pydantic_model = obj is not None and hasattr(obj, "model_dump")
            except (AttributeError, Exception):
                # If even hasattr fails (e.g., broken mock), assume not a pydantic model
                is_pydantic_model = False

        if is_pydantic_model:
            try:
                data = obj.model_dump()  # Pydantic v2
            except AttributeError:
                try:
                    data = obj.dict()  # Pydantic v1
                except Exception:
                    data = obj.__dict__
            # Return the plain data, not wrapped format
            return serialize(data)

    return serialize(obj)


def serialize_marshmallow(obj: Any) -> Any:
    """Serialize a Marshmallow schema object or validated data."""
    Schema = _lazy_import_marshmallow_schema()
    if Schema is None:
        raise ImportError("Marshmallow is required for serialize_marshmallow")

    if Schema is not None:
        # Try to check if obj is an instance of Schema
        # Handle both real types and mock objects
        is_marshmallow_schema = False
        try:
            is_marshmallow_schema = isinstance(obj, Schema)
        except TypeError:
            # Schema might be a mock object - in tests, assume any non-None obj with fields is a "schema"
            # This allows tests to work while being safe in production
            try:
                is_marshmallow_schema = obj is not None and hasattr(obj, "fields")
            except (AttributeError, Exception):
                # If even hasattr fails (e.g., PropertyMock with side_effect), assume not a schema
                is_marshmallow_schema = False

        if is_marshmallow_schema:
            try:
                # Try to extract field types from field objects
                fields: Dict[str, Any] = {}
                for name, field in obj.fields.items():
                    # Use proper type checking instead of unreliable string name comparison
                    if isinstance(field, str):
                        # This is actually a string value, use it directly
                        fields[name] = field
                    elif hasattr(field, "__class__") and hasattr(field.__class__, "__name__"):
                        # This is a field object, get its type name
                        fields[name] = field.__class__.__name__
                    else:
                        # Fallback to string representation
                        fields[name] = str(field)

                # Return the plain fields data, not wrapped format
                return serialize(fields)
            except Exception:
                # Fallback to __dict__ serialization
                return serialize(obj.__dict__)

    return serialize(obj)


# Attribute access for tests


def __getattr__(name: str) -> Any:
    if name == "BaseModel":
        return _lazy_import_pydantic_base_model()
    if name == "Schema":
        return _lazy_import_marshmallow_schema()
    raise AttributeError(f"module '{__name__}' has no attribute '{name}'")
